summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--ChangeLog10
-rw-r--r--RELEASE-DATE2
-rw-r--r--VERSION2
-rw-r--r--dist/tiff.alpha2
-rw-r--r--html/index.html8
-rw-r--r--tools/gif2tiff.c4
-rw-r--r--tools/pal2rgb.c4
-rw-r--r--tools/ppm2tiff.c4
-rw-r--r--tools/ras2tiff.c4
-rw-r--r--tools/rgb2ycbcr.c4
-rw-r--r--tools/sgi2tiff.c4
-rw-r--r--tools/sgisv.c4
-rw-r--r--tools/tiff2bw.c4
-rw-r--r--tools/tiff2rgba.c3
-rw-r--r--tools/tiffcp.c4
-rw-r--r--tools/tiffdither.c4
-rw-r--r--tools/tiffmedian.c6
17 files changed, 42 insertions, 31 deletions
diff --git a/ChangeLog b/ChangeLog
index 50ab1e89..0e083e31 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,8 +1,16 @@
+Mon Dec 27 12:13:39 EST 1999 Mike Welles <mike@onshore.com>
+
+ * Created lzw compression kit, as a new module (libtiff-lzw-compression-kit).
+
+ * Altered descriptions in tools to reflect "by default" lzw not supported
+
+ * Updated index.html to note lzw compression kit.
+
Tue Dec 21 14:01:51 1999 Frank Warmerdam <warmerda@gdal.velocet.ca>
* Added fax3sm_winnt.c to distribution list in Makefile.in.
-Tue Dec 21 11:04:45 EST 1999 Mike Welles <mike@onshore.com>
+Tue Dec 21 11:04:45 EST 1999 Mike Welles <mike@onshore.com> ***3.5.4 release***
* Aadded Pixar tag support. Contributed by Phil Beffery <phil@pixar.com>
diff --git a/RELEASE-DATE b/RELEASE-DATE
index 89275f1e..2bc64e77 100644
--- a/RELEASE-DATE
+++ b/RELEASE-DATE
@@ -1 +1 @@
-11/30/1999
+12/21/1999
diff --git a/VERSION b/VERSION
index afe2f810..65afb3b8 100644
--- a/VERSION
+++ b/VERSION
@@ -1 +1 @@
-3.5.
+3.5.4
diff --git a/dist/tiff.alpha b/dist/tiff.alpha
index 0ed034b3..a78fd0b8 100644
--- a/dist/tiff.alpha
+++ b/dist/tiff.alpha
@@ -1 +1 @@
-define ALPHA 4
+define ALPHA
diff --git a/html/index.html b/html/index.html
index a8e5ef3b..1a012f15 100644
--- a/html/index.html
+++ b/html/index.html
@@ -18,14 +18,16 @@ TIFF Software
<B>Latest Software</B>: <A HREF="v3.5.4.html">v3.5.4</A><BR>
<B>Master FTP Site</B>: <A HREF="ftp://ftp.onshore.com/pub/libtiff">ftp.onshore.com</A> , directory pub/libtiff (Active mode FTP only!)<BR>
<B>HTTP Download</B>: <A HREF=http://www.libtiff.org/tiff-v3.5.4.tar.gz>http://www.libtiff.org/tiff-v3.5.4.tar.gz</a>, <A HREF=http://www.libtiff.org/tiff-v3.5.4.zip>http://www.libtiff.org/tiff-v3.5.4.zip</a><BR>
+<B>LZW Compression Kit:</B> <A HREF="libtiff-lzw-compression-kit.tar.gz">libtiff-lzw-compression-kit</A><BR>
<B>Mailing List</B>: <a href=mailto:tiff@olympiakos.com>tiff@olympiakos.com</a> <BR>
<B>Mailing List Subscription</b>: <a href=mailto:tiff-request@olympiakos.com>tiff-request@olympiakos.com</a> ("subscribe tiff" in body of message). <BR>
<B>Mailing List Archive</b>: <A HREF= http://www.remotesensing.org/lists/libtiff_archive/maillist.html>http://www.remotesensing.org/lists/libtiff_archive/maillist.html</A> <BR>
-<B>Anon CVS</B>:<pre>
+<B>Anonymous CVS</B>:<pre>
export CVSROOT=:pserver:anonymous@remotesensing.org:/cvsroot
cvs login # use password "anonymous"
cvs checkout libtiff
-</pre>
+ cvs checkout libtiff-lzw-compression-kit
+</pre>
<br>
<P>
@@ -82,7 +84,7 @@ The following sections are included in this documentation:
<P>
<HR>
<em>
-$Id: index.html,v 1.23 1999-12-21 21:37:25 mwelles Exp $
+$Id: index.html,v 1.24 1999-12-27 17:35:01 mwelles Exp $
</em>
</BODY>
diff --git a/tools/gif2tiff.c b/tools/gif2tiff.c
index 194d1452..cfc9dc97 100644
--- a/tools/gif2tiff.c
+++ b/tools/gif2tiff.c
@@ -1,4 +1,4 @@
-/* $Header: /cvs/maptools/cvsroot/libtiff/tools/gif2tiff.c,v 1.2 1999-12-21 17:03:03 mwelles Exp $ */
+/* $Header: /cvs/maptools/cvsroot/libtiff/tools/gif2tiff.c,v 1.3 1999-12-27 17:35:01 mwelles Exp $ */
/*
* Copyright (c) 1990-1997 Sam Leffler
@@ -70,7 +70,7 @@ char* stuff[] = {
" -r # make each strip have no more than # rows",
"",
" -c lzw[:opts] compress output with Lempel-Ziv & Welch encoding",
-" (no longer supported due to Unisys patent enforcement)",
+" (no longer supported by default due to Unisys patent enforcement)",
" -c zip[:opts] compress output with deflate encoding",
" -c packbits compress output with packbits encoding",
" -c none use no compression algorithm on output",
diff --git a/tools/pal2rgb.c b/tools/pal2rgb.c
index a31910cd..9f6b9e23 100644
--- a/tools/pal2rgb.c
+++ b/tools/pal2rgb.c
@@ -1,4 +1,4 @@
-/* $Header: /cvs/maptools/cvsroot/libtiff/tools/pal2rgb.c,v 1.2 1999-12-21 17:03:03 mwelles Exp $ */
+/* $Header: /cvs/maptools/cvsroot/libtiff/tools/pal2rgb.c,v 1.3 1999-12-27 17:35:01 mwelles Exp $ */
/*
* Copyright (c) 1988-1997 Sam Leffler
@@ -362,7 +362,7 @@ char* stuff[] = {
" -C 16 assume 16-bit colormap values",
"",
" -c lzw[:opts] compress output with Lempel-Ziv & Welch encoding",
-" (no longer supported due to Unisys patent enforcement)",
+" (no longer supported by default due to Unisys patent enforcement)",
" -c zip[:opts] compress output with deflate encoding",
" -c packbits compress output with packbits encoding",
" -c none use no compression algorithm on output",
diff --git a/tools/ppm2tiff.c b/tools/ppm2tiff.c
index 53442dc8..bee5bc17 100644
--- a/tools/ppm2tiff.c
+++ b/tools/ppm2tiff.c
@@ -1,4 +1,4 @@
-/* $Header: /cvs/maptools/cvsroot/libtiff/tools/ppm2tiff.c,v 1.2 1999-12-21 17:03:03 mwelles Exp $ */
+/* $Header: /cvs/maptools/cvsroot/libtiff/tools/ppm2tiff.c,v 1.3 1999-12-27 17:35:01 mwelles Exp $ */
/*
* Copyright (c) 1991-1997 Sam Leffler
@@ -215,7 +215,7 @@ char* stuff[] = {
"",
" -c jpeg[:opts] compress output with JPEG encoding",
" -c lzw[:opts] compress output with Lempel-Ziv & Welch encoding",
-" (no longer supported due to Unisys patent enforcement)",
+" (no longer supported by default due to Unisys patent enforcement)",
" -c zip[:opts] compress output with deflate encoding",
" -c packbits compress output with packbits encoding",
" -c none use no compression algorithm on output",
diff --git a/tools/ras2tiff.c b/tools/ras2tiff.c
index bbb63eed..e448a9e9 100644
--- a/tools/ras2tiff.c
+++ b/tools/ras2tiff.c
@@ -1,4 +1,4 @@
-/* $Header: /cvs/maptools/cvsroot/libtiff/tools/ras2tiff.c,v 1.2 1999-12-21 17:03:03 mwelles Exp $ */
+/* $Header: /cvs/maptools/cvsroot/libtiff/tools/ras2tiff.c,v 1.3 1999-12-27 17:35:01 mwelles Exp $ */
/*
* Copyright (c) 1988-1997 Sam Leffler
@@ -236,7 +236,7 @@ char* stuff[] = {
" -r # make each strip have no more than # rows",
"",
" -c lzw[:opts] compress output with Lempel-Ziv & Welch encoding",
-" (no longer supported due to Unisys patent enforcement)",
+" (no longer supported by default due to Unisys patent enforcement)",
" -c zip[:opts] compress output with deflate encoding",
" -c jpeg[:opts]compress output with JPEG encoding",
" -c packbits compress output with packbits encoding",
diff --git a/tools/rgb2ycbcr.c b/tools/rgb2ycbcr.c
index aefa9f2b..a2771757 100644
--- a/tools/rgb2ycbcr.c
+++ b/tools/rgb2ycbcr.c
@@ -1,4 +1,4 @@
-/* $Header: /cvs/maptools/cvsroot/libtiff/tools/rgb2ycbcr.c,v 1.2 1999-12-21 17:03:03 mwelles Exp $ */
+/* $Header: /cvs/maptools/cvsroot/libtiff/tools/rgb2ycbcr.c,v 1.3 1999-12-27 17:35:01 mwelles Exp $ */
/*
* Copyright (c) 1991-1997 Sam Leffler
@@ -321,7 +321,7 @@ static char* usageMsg[] = {
"where comp is one of the following compression algorithms:\n",
" jpeg\t\tJPEG encoding\n",
" lzw\t\tLempel-Ziv & Welch encoding\n",
- " (lzw no longer supported due to Unisys patent enforcement)",
+ " (lzw no longer supported by default due to Unisys patent enforcement)",
" packbits\tPackBits encoding\n",
" none\t\tno compression\n",
"and the other options are:\n",
diff --git a/tools/sgi2tiff.c b/tools/sgi2tiff.c
index 474c0d49..a565acff 100644
--- a/tools/sgi2tiff.c
+++ b/tools/sgi2tiff.c
@@ -1,4 +1,4 @@
-/* $Header: /cvs/maptools/cvsroot/libtiff/tools/sgi2tiff.c,v 1.2 1999-12-21 17:03:03 mwelles Exp $ */
+/* $Header: /cvs/maptools/cvsroot/libtiff/tools/sgi2tiff.c,v 1.3 1999-12-27 17:35:01 mwelles Exp $ */
/*
* Copyright (c) 1991-1997 Sam Leffler
@@ -292,7 +292,7 @@ char* stuff[] = {
" -f msb2lsb force msb-to-lsb FillOrder for output",
"",
" -c lzw[:opts] compress output with Lempel-Ziv & Welch encoding",
-" (no longer supported due to Unisys patent enforcement)",
+" (no longer supported by default due to Unisys patent enforcement)",
" -c zip[:opts] compress output with deflate encoding",
" -c jpeg[:opts]compress output with JPEG encoding",
" -c packbits compress output with packbits encoding",
diff --git a/tools/sgisv.c b/tools/sgisv.c
index dd9b61d3..6218cfdb 100644
--- a/tools/sgisv.c
+++ b/tools/sgisv.c
@@ -1,4 +1,4 @@
-/* $Header: /cvs/maptools/cvsroot/libtiff/tools/sgisv.c,v 1.2 1999-12-21 17:03:03 mwelles Exp $ */
+/* $Header: /cvs/maptools/cvsroot/libtiff/tools/sgisv.c,v 1.3 1999-12-27 17:35:01 mwelles Exp $ */
/*
* Copyright (c) 1990-1997 Sam Leffler
@@ -124,7 +124,7 @@ char* stuff[] = {
" -r # make each strip have no more than # rows",
"",
" -c lzw[:opts] compress output with Lempel-Ziv & Welch encoding",
-" (no longer supported due to Unisys patent enforcement)",
+" (no longer supported by default due to Unisys patent enforcement)",
" -c jpeg[:opts]compress output with JPEG encoding",
" -c packbits compress output with packbits encoding",
" -c none use no compression algorithm on output",
diff --git a/tools/tiff2bw.c b/tools/tiff2bw.c
index 730eaf08..54e4b671 100644
--- a/tools/tiff2bw.c
+++ b/tools/tiff2bw.c
@@ -1,4 +1,4 @@
-/* $Header: /cvs/maptools/cvsroot/libtiff/tools/tiff2bw.c,v 1.2 1999-12-21 17:03:03 mwelles Exp $ */
+/* $Header: /cvs/maptools/cvsroot/libtiff/tools/tiff2bw.c,v 1.3 1999-12-27 17:35:01 mwelles Exp $ */
/*
* Copyright (c) 1988-1997 Sam Leffler
@@ -375,7 +375,7 @@ char* stuff[] = {
" -r # make each strip have no more than # rows",
"",
" -c lzw[:opts] compress output with Lempel-Ziv & Welch encoding",
-" (no longer supported due to Unisys patent enforcement)",
+" (no longer supported by default due to Unisys patent enforcement)",
" -c zip[:opts] compress output with deflate encoding",
" -c packbits compress output with packbits encoding",
" -c g3[:opts] compress output with CCITT Group 3 encoding",
diff --git a/tools/tiff2rgba.c b/tools/tiff2rgba.c
index c03dfe0d..ef9e3a50 100644
--- a/tools/tiff2rgba.c
+++ b/tools/tiff2rgba.c
@@ -1,4 +1,4 @@
-/* $Header: /cvs/maptools/cvsroot/libtiff/tools/tiff2rgba.c,v 1.2 1999-12-04 20:48:27 warmerda Exp $ */
+/* $Header: /cvs/maptools/cvsroot/libtiff/tools/tiff2rgba.c,v 1.3 1999-12-27 17:35:01 mwelles Exp $ */
/*
* Copyright (c) 1991-1997 Sam Leffler
@@ -434,6 +434,7 @@ static char* usageMsg[] = {
"where comp is one of the following compression algorithms:\n",
" jpeg\t\tJPEG encoding\n",
" lzw\t\tLempel-Ziv & Welch encoding\n",
+ " (lzw compression unsupported by default due to Unisys patent enforcement)\n",
" packbits\tPackBits encoding\n",
" none\t\tno compression\n",
"and the other options are:\n",
diff --git a/tools/tiffcp.c b/tools/tiffcp.c
index 9b7efc5a..8fb11946 100644
--- a/tools/tiffcp.c
+++ b/tools/tiffcp.c
@@ -1,4 +1,4 @@
-/* $Header: /cvs/maptools/cvsroot/libtiff/tools/tiffcp.c,v 1.3 1999-12-21 17:03:03 mwelles Exp $ */
+/* $Header: /cvs/maptools/cvsroot/libtiff/tools/tiffcp.c,v 1.4 1999-12-27 17:35:01 mwelles Exp $ */
/*
* Copyright (c) 1988-1997 Sam Leffler
@@ -265,7 +265,7 @@ char* stuff[] = {
" -f msb2lsb force msb-to-lsb FillOrder for output",
"",
" -c lzw[:opts] compress output with Lempel-Ziv & Welch encoding",
-" (no longer supported due to Unisys patent enforcement)",
+" (no longer supported by default due to Unisys patent enforcement)",
" -c zip[:opts] compress output with deflate encoding",
" -c jpeg[:opts]compress output with JPEG encoding",
" -c packbits compress output with packbits encoding",
diff --git a/tools/tiffdither.c b/tools/tiffdither.c
index 0ad89f15..0344f90a 100644
--- a/tools/tiffdither.c
+++ b/tools/tiffdither.c
@@ -1,4 +1,4 @@
-/* $Header: /cvs/maptools/cvsroot/libtiff/tools/tiffdither.c,v 1.2 1999-12-21 17:03:03 mwelles Exp $ */
+/* $Header: /cvs/maptools/cvsroot/libtiff/tools/tiffdither.c,v 1.3 1999-12-27 17:35:01 mwelles Exp $ */
/*
* Copyright (c) 1988-1997 Sam Leffler
@@ -282,7 +282,7 @@ char* stuff[] = {
" -f lsb2msb force lsb-to-msb FillOrder for output",
" -f msb2lsb force msb-to-lsb FillOrder for output",
" -c lzw[:opts] compress output with Lempel-Ziv & Welch encoding",
-" (no longer supported due to Unisys patent enforcement)",
+" (no longer supported by default due to Unisys patent enforcement)",
" -c zip[:opts] compress output with deflate encoding",
" -c packbits compress output with packbits encoding",
" -c g3[:opts] compress output with CCITT Group 3 encoding",
diff --git a/tools/tiffmedian.c b/tools/tiffmedian.c
index 1ef6dd6b..f362ce29 100644
--- a/tools/tiffmedian.c
+++ b/tools/tiffmedian.c
@@ -1,4 +1,4 @@
-/* $Header: /cvs/maptools/cvsroot/libtiff/tools/tiffmedian.c,v 1.2 1999-12-21 17:03:03 mwelles Exp $ */
+/* $Header: /cvs/maptools/cvsroot/libtiff/tools/tiffmedian.c,v 1.3 1999-12-27 17:35:01 mwelles Exp $ */
/*
* Apply median cut on an image.
@@ -7,7 +7,7 @@
* -C n - set colortable size. Default is 256.
* -f - use Floyd-Steinberg dithering.
* -c lzw - compress output with LZW
* (no longer supported due to unisys patent enforcement)
* -c none - use no compression on output
* -c packbits - use packbits compression on output
* -r n - create output with n rows/strip of data
@@ -314,7 +314,7 @@ char* stuff[] = {
" -C # create a colormap with # entries",
" -f use Floyd-Steinberg dithering",
" -c lzw[:opts] compress output with Lempel-Ziv & Welch encoding",
-" (no longer supported due to Unisys patent enforcement)",
+" (no longer supported by default due to Unisys patent enforcement)",
" -c zip[:opts] compress output with deflate encoding",
" -c packbits compress output with packbits encoding",
" -c none use no compression algorithm on output",
@@ -7,7 +7,7 @@
* -f - use Floyd-Steinberg dithering.
* -c lzw - compress output with LZW
- * (no longer supported due to unisys patent enforcement)
+ * (no longer supported by default due to unisys patent enforcement)
* -c none - use no compression on output
* -c packbits - use packbits compression on output